from distutils.core import setup

setup(
    name='mitsubishi_echonet',
    version='0.1.3',
    author='Scott Phillips',
    author_email='jrh@example.com',
    packages=['mitsubishi_echonet'],
    url='http://pypi.python.org/pypi/mitsubishi_echonet/',
    license='LICENSE.txt',
    description='A library for interfacing with Mitsubishi HVAC via the Echonet lite protocol.',
    long_description=open('README.md').read(),
    # install_requires=[
    #    "Django >= 1.1.1",
    #    "caldav == 0.1.4",
    #],
)
